@@ -9,8 +9,8 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.066-1-gc7fc701
-$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.067';
+# git description: 0.067-5-gac99ee0
+$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.068';
 
 # ABSTRACT: Zilla your distributions like RSRCHBOY!
 
@@ -66,7 +66,7 @@ has _copy_from_build => (
     builder => sub {
         my ($self) = @_;
 
-        my @copy = (qw{ LICENSE cpanfile });
+        my @copy = (qw{ LICENSE });
         push @copy, 'Makefile.PL'
             if $self->is_app;
 
@@ -265,13 +265,6 @@ sub configure {
         [ AutoPrereqs => $autoprereq_opts ],
         [ Prepender   => $prepender_opts  ],
 
-        [ Prereqs => AuthorBundleDevelopRequires => {
-            -phase        => 'develop',
-            -relationship => 'requires',
-
-            $self->meta->name  => $self->VERSION || 0,
-        } ],
-
         $self->author_tests,
         $self->meta_provider_plugins,
         $self->release_plugins,
@@ -359,7 +352,7 @@ Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-This document describes version 0.067 of Dist::Zilla::PluginBundle::RSRCHBOY - released May 05, 2016 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.068 of Dist::Zilla::PluginBundle::RSRCHBOY - released October 09, 2016 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
@@ -465,7 +458,7 @@ L<Config::MVP::Slicer|Config::MVP::Slicer>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/RsrchBoy/dist-zilla-pluginbundle-rsrchboy/issues
+L<https://github.com/RsrchBoy/dist-zilla-pluginbundle-rsrchboy/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
