@@ -9,7 +9,7 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY::Role::Git;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-$Dist::Zilla::PluginBundle::RSRCHBOY::Role::Git::VERSION = '0.067';
+$Dist::Zilla::PluginBundle::RSRCHBOY::Role::Git::VERSION = '0.068';
 # ABSTRACT: A helper role for Git::Raw operations
 
 use Moose::Role;
@@ -54,7 +54,7 @@ Dist::Zilla::PluginBundle::RSRCHBOY::Role::Git - A helper role for Git::Raw oper
 
 =head1 VERSION
 
-This document describes version 0.067 of Dist::Zilla::PluginBundle::RSRCHBOY::Role::Git - released May 05, 2016 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.068 of Dist::Zilla::PluginBundle::RSRCHBOY::Role::Git - released October 09, 2016 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 ATTRIBUTES
 
@@ -88,7 +88,7 @@ L<Dist::Zilla::PluginBundle::RSRCHBOY|Dist::Zilla::PluginBundle::RSRCHBOY>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/RsrchBoy/dist-zilla-pluginbundle-rsrchboy/issues
+L<https://github.com/RsrchBoy/dist-zilla-pluginbundle-rsrchboy/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
