@@ -9,7 +9,7 @@
 #
 package Pod::Weaver::PluginBundle::RSRCHBOY;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-$Pod::Weaver::PluginBundle::RSRCHBOY::VERSION = '0.067';
+$Pod::Weaver::PluginBundle::RSRCHBOY::VERSION = '0.068';
 # ABSTRACT: Document your modules like RSRCHBOY does
 
 use strict;
@@ -87,7 +87,7 @@ Pod::Weaver::PluginBundle::RSRCHBOY - Document your modules like RSRCHBOY does
 
 =head1 VERSION
 
-This document describes version 0.067 of Pod::Weaver::PluginBundle::RSRCHBOY - released May 05, 2016 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.068 of Pod::Weaver::PluginBundle::RSRCHBOY - released October 09, 2016 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
@@ -163,7 +163,7 @@ L<Dist::Zilla::PluginBundle::RSRCHBOY|Dist::Zilla::PluginBundle::RSRCHBOY>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/RsrchBoy/dist-zilla-pluginbundle-rsrchboy/issues
+L<https://github.com/RsrchBoy/dist-zilla-pluginbundle-rsrchboy/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
