@@ -9,7 +9,7 @@
 #
 package Pod::Weaver::Section::RSRCHBOY::RequiredAttributes;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-$Pod::Weaver::Section::RSRCHBOY::RequiredAttributes::VERSION = '0.067';
+$Pod::Weaver::Section::RSRCHBOY::RequiredAttributes::VERSION = '0.068';
 # ABSTRACT: Prefaced required attributes section
 
 use Moose;
@@ -45,7 +45,7 @@ Pod::Weaver::Section::RSRCHBOY::RequiredAttributes - Prefaced required attribute
 
 =head1 VERSION
 
-This document describes version 0.067 of Pod::Weaver::Section::RSRCHBOY::RequiredAttributes - released May 05, 2016 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.068 of Pod::Weaver::Section::RSRCHBOY::RequiredAttributes - released October 09, 2016 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SEE ALSO
 
@@ -62,7 +62,7 @@ L<Dist::Zilla::PluginBundle::RSRCHBOY|Dist::Zilla::PluginBundle::RSRCHBOY>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/RsrchBoy/dist-zilla-pluginbundle-rsrchboy/issues
+L<https://github.com/RsrchBoy/dist-zilla-pluginbundle-rsrchboy/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
